==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/tests/test.R <==
library(GeneticsBase)


if(FALSE)
  {
    ####
    ## for manual debugging
    ####

    library(gtools)
    library(gdata)
    
    ## Explicitly source files when debugging
    PATH=("~/src/R/r-genetics/GeneticsBase/R")
    source(file.path(PATH,"LD.R"))
    source(file.path(PATH,"LDband.R"))
    source(file.path(PATH,"carrier.R"))
    source(file.path(PATH,"geneSet.R"))
    for(file in grep("\\.R$",list.files(PATH),value=TRUE))
      {
        cat("Loading `",file,"'...\n",sep="")
        source(file.path(PATH,file))
      }
  }


tTabList <- makeTransTableList(c("Bb", "ATG"), c("Generic", "SNP"))
locus <- c("c104t", "c2249t")
ttab <- c("SNP", "Generic")
minfo <- makeMarkerInfo(locus, ttab)
misscodes <- list(Generic = c("NA", ".", "-"), SNP = "N")
r1 <- c(1, 2, 1, 1)
r2 <- c(1, 2, 3, 2)
data <- rbind(r1, r2) # callCodes
dimnames(data) <- list(locus, paste("Sample", seq(along = r1),
        sep = "."))
decodeCallCodes(data, tTabList, minfo)

## Creating an arbitrary sampleInfo
sampleInfo <- data.frame(matrix(letters[1:8], nrow=4, byrow=TRUE))

aCodeSet2 <- new('geneSet', callCodes = data, transTables =
        tTabList, missingCodes = misscodes, markerInfo = minfo, phase =
        list(FALSE), ploidy = 2)

aCodeSet2 <- geneSet(
                     callCodes = data,
                     #errorMetrics = matrix(nrow=0,ncol=0),
                     transTables = tTabList,
                     missingCodes = misscodes,
                     markerInfo = minfo,
                     sampleInfo = sampleInfo,
                     phase = list(FALSE),
                     ploidy = 2
        )

        

GeneticsBase:::extractAlleles(aCodeSet2)
alleleLevels(aCodeSet2)


homozygote(aCodeSet2)
decodeCallCodes(data, tTabList, minfo)

aCodeSet2@transTables
aCodeSet2@callCodes

LD(aCodeSet2)

## Find the alleles - testing...
object <- aCodeSet2
allele.set <- decodeCallCodes(object@callCodes,
                              object@transTables,
                              object@markerInfo)

allele.set
aa <- strsplit(allele.set[1,], NULL)


decodeCallCodes(data, tTabList, minfo)

homozygote(object)



allele.matrix <- alleles(object)

allele.matrix[,1:2]
allele.names <- alleleLevels(object)

alleles(aCodeSet2, which=0)
homozygote(aCodeSet2)
homozygote(aCodeSet2, allele.names="A")
homozygote(aCodeSet2, marker="c104t")
homozygote(aCodeSet2, marker="c104t", allele.names="A")


homozygote(aCodeSet2)
homozygote(aCodeSet2, allele.names="A")
homozygote(aCodeSet2, allele.names=list("A"))
homozygote(aCodeSet2, allele.names=list("B"))
homozygote(aCodeSet2, allele.names=list())
homozygote(aCodeSet2, allele.names=c())

homozygote(aCodeSet2, marker="c104t")
homozygote(aCodeSet2, marker="c104t", allele.names="A")
homozygote(aCodeSet2, marker="c104t", allele.names="B")
homozygote(aCodeSet2, marker="c104t", allele.names=NA)
homozygote(aCodeSet2, marker="c104t", allele.names=character(0))
homozygote(aCodeSet2, marker="c104t", allele.names=list())
homozygote(aCodeSet2, marker="c104t", allele.names=7)

extractAlleles(object)
extractAlleles(object, which=0)
extractAlleles(object, which=0)
extractAlleles(object, which=c(1,2))

object@transTables


## showGeneSet(object)


LD(object)

### The following function displays teh diagonal of a matrix - useful
### fro displaying the results of large LD matrices.
#display.diag <- function(x, left, right, MAX.LEFT = 5, MAX.RIGHT = 5, THRESHOLD)
#  {
#    if (!is.matrix(x) )
#      stop(paste("x must be a mtrix"))
    
#    if( missing(left) & missing(right) )
#      left <- right <- floor(nrow(x)/2)

#    if (missing(left) & !missing(right) )
#      left <- right
    
#    if (missing(right) & !missing(left) )
#       right <- left 

#    if ( left > floor(nrow(x)/2) || right > floor(nrow(x)/2) )
#       left <- right <- floor(nrow(x)/2)

#    if( left > MAX.LEFT)
#      left <- MAX.LEFT

#    if ( right > MAX.RIGHT)
#      right <- MAX.RIGHT

#    temp <- matrix("", nrow(x), ncol(x) )
#    if (missing(THRESHOLD))
#      THRESHOLD <- 0 ## For testing sake
    
#    temp[x>THRESHOLD] <- x[x>THRESHOLD]
#    print(temp, quote=FALSE)

### ALTERNATIVE WAY!!

    
#for (i in 1:nrow(x))
#  for (j in 1:ncol(x))
#    {
#      k <- which(i==j)
#      temp.left <- ifelse(k-left > 0,
#                          k-left,
#                          1)
#      temp.right <- ifelse(k+right > ncol(x),
#                          k+right,
#                          ncol(x))
      
#      temp[i,c((k-left):(k+right))] <-
#        x[i,c((k-left):(k+right))]
#    }

#    print(temp, quote=FALSE)
    
#  }

### Testing the above function
#temp1 <-  matrix(rep(seq(10), 10), nrow=10, byrow=TRUE)

#aa <- display.diag(temp1, THRESHOLD=5)



#upper.tri(temp1)

#temp1[temp1 <= 5]

      
#temp2 <- rbind(
#               c(1, rep(0,5)),
#               c(2,3, rep(0,4)),
#               c(0,3:5, rep(0,2)),
#               c(rep(0,3),4:5, rep(0,1))
#               ) 

#temp2
#temp3 <- matrix("", nrow(temp2), ncol(temp2))
#temp3[temp2>0] <- temp2[temp2>0]
#print(temp3, quote=FALSE)




#mark.temp <- 0

#for(i in seq(nrow(temp2)) )
#  for (j in seq(ncol(temp2)) )
#    ifelse(temp2[i,j] > mark.temp,
#           temp2[i,j]),
#           print(" "
#  if ((i+j) %in% row.find)
#  print(temp2[i+j])




aa <- extractAlleles(object, which=c(1,2))
value="A"
apply(aa, 1, function(x) sum(x==value))
 extractAlleles(object, which=0)


unique(as.character(alleles(object)))

carrier(object)
carrier(object, allele.names="A")
carrier(object, allele.names="A")

carrier(object, allele.names=c("T","A"))



alleleCount(object,value="A")
alleleCount(object,value=alleleLevels(object))
as.character(unlist(alleleLevels(object)))



aa <- markerNames(object)

as.vector(aa)

markerInfo(object)


marker="c104t"

match(marker, as.vector(markerNames(object)))

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/tests/test.R <==
library(GeneticsBase)


if(FALSE)
  {
    ####
    ## for manual debugging
    ####

    library(gtools)
    library(gdata)
    
    ## Explicitly source files when debugging
    PATH=("~/src/R/r-genetics/GeneticsBase/R")
    source(file.path(PATH,"LD.R"))
    source(file.path(PATH,"LDband.R"))
    source(file.path(PATH,"carrier.R"))
    source(file.path(PATH,"geneSet.R"))
    for(file in grep("\\.R$",list.files(PATH),value=TRUE))
      {
        cat("Loading `",file,"'...\n",sep="")
        source(file.path(PATH,file))
      }
  }


tTabList <- makeTransTableList(c("Bb", "ATG"), c("Generic", "SNP"))
locus <- c("c104t", "c2249t")
ttab <- c("SNP", "Generic")
minfo <- makeMarkerInfo(locus, ttab)
misscodes <- list(Generic = c("NA", ".", "-"), SNP = "N")
r1 <- c(1, 2, 1, 1)
r2 <- c(1, 2, 3, 2)
data <- rbind(r1, r2) # callCodes
dimnames(data) <- list(locus, paste("Sample", seq(along = r1),
        sep = "."))
decodeCallCodes(data, tTabList, minfo)

## Creating an arbitrary sampleInfo
#sampleInfo <- data.frame(matrix(letters[1:8], nrow=4, byrow=TRUE))
sampleInfo <- data.frame(pid=rep(1,4), id=1:4, fid=rep(0,4), mid=rep(0,4), sex=sample(1:2,4,rep=TRUE), affected=sample(1:2, 4, rep=TRUE))

aCodeSet2 <- new('geneSet', callCodes = data, transTables =
        tTabList, missingCodes = misscodes, markerInfo = minfo, phase =
        list(FALSE), ploidy = 2)

aCodeSet2 <- geneSet(
                     callCodes = data,
                     #errorMetrics = matrix(nrow=0,ncol=0),
                     transTables = tTabList,
                     missingCodes = misscodes,
                     markerInfo = minfo,
                     sampleInfo = sampleInfo,
                     phase = list(FALSE),
                     ploidy = 2
        )

        

GeneticsBase:::extractAlleles(aCodeSet2)
alleleLevels(aCodeSet2)


homozygote(aCodeSet2)
decodeCallCodes(data, tTabList, minfo)

aCodeSet2@transTables
aCodeSet2@callCodes

LD(aCodeSet2)

## Find the alleles - testing...
object <- aCodeSet2
allele.set <- decodeCallCodes(object@callCodes,
                              object@transTables,
                              object@markerInfo)

allele.set
aa <- strsplit(allele.set[1,], NULL)


decodeCallCodes(data, tTabList, minfo)

homozygote(object)



allele.matrix <- alleles(object)

allele.matrix[,1:2]
allele.names <- alleleLevels(object)

alleles(aCodeSet2, which=0)
homozygote(aCodeSet2)
homozygote(aCodeSet2, allele.names="A")
homozygote(aCodeSet2, marker="c104t")
homozygote(aCodeSet2, marker="c104t", allele.names="A")


homozygote(aCodeSet2)
homozygote(aCodeSet2, allele.names="A")
homozygote(aCodeSet2, allele.names=list("A"))
homozygote(aCodeSet2, allele.names=list("B"))
homozygote(aCodeSet2, allele.names=list())
homozygote(aCodeSet2, allele.names=c())

homozygote(aCodeSet2, marker="c104t")
homozygote(aCodeSet2, marker="c104t", allele.names="A")
homozygote(aCodeSet2, marker="c104t", allele.names="B")
homozygote(aCodeSet2, marker="c104t", allele.names=NA)
homozygote(aCodeSet2, marker="c104t", allele.names=character(0))
homozygote(aCodeSet2, marker="c104t", allele.names=list())
homozygote(aCodeSet2, marker="c104t", allele.names=7)

extractAlleles(object)
extractAlleles(object, which=0)
extractAlleles(object, which=0)
extractAlleles(object, which=c(1,2))

object@transTables


## showGeneSet(object)


LD(object)

### The following function displays teh diagonal of a matrix - useful
### fro displaying the results of large LD matrices.
#display.diag <- function(x, left, right, MAX.LEFT = 5, MAX.RIGHT = 5, THRESHOLD)
#  {
#    if (!is.matrix(x) )
#      stop(paste("x must be a mtrix"))
    
#    if( missing(left) & missing(right) )
#      left <- right <- floor(nrow(x)/2)

#    if (missing(left) & !missing(right) )
#      left <- right
    
#    if (missing(right) & !missing(left) )
#       right <- left 

#    if ( left > floor(nrow(x)/2) || right > floor(nrow(x)/2) )
#       left <- right <- floor(nrow(x)/2)

#    if( left > MAX.LEFT)
#      left <- MAX.LEFT

#    if ( right > MAX.RIGHT)
#      right <- MAX.RIGHT

#    temp <- matrix("", nrow(x), ncol(x) )
#    if (missing(THRESHOLD))
#      THRESHOLD <- 0 ## For testing sake
    
#    temp[x>THRESHOLD] <- x[x>THRESHOLD]
#    print(temp, quote=FALSE)

### ALTERNATIVE WAY!!

    
#for (i in 1:nrow(x))
#  for (j in 1:ncol(x))
#    {
#      k <- which(i==j)
#      temp.left <- ifelse(k-left > 0,
#                          k-left,
#                          1)
#      temp.right <- ifelse(k+right > ncol(x),
#                          k+right,
#                          ncol(x))
      
#      temp[i,c((k-left):(k+right))] <-
#        x[i,c((k-left):(k+right))]
#    }

#    print(temp, quote=FALSE)
    
#  }

### Testing the above function
#temp1 <-  matrix(rep(seq(10), 10), nrow=10, byrow=TRUE)

#aa <- display.diag(temp1, THRESHOLD=5)



#upper.tri(temp1)

#temp1[temp1 <= 5]

      
#temp2 <- rbind(
#               c(1, rep(0,5)),
#               c(2,3, rep(0,4)),
#               c(0,3:5, rep(0,2)),
#               c(rep(0,3),4:5, rep(0,1))
#               ) 

#temp2
#temp3 <- matrix("", nrow(temp2), ncol(temp2))
#temp3[temp2>0] <- temp2[temp2>0]
#print(temp3, quote=FALSE)




#mark.temp <- 0

#for(i in seq(nrow(temp2)) )
#  for (j in seq(ncol(temp2)) )
#    ifelse(temp2[i,j] > mark.temp,
#           temp2[i,j]),
#           print(" "
#  if ((i+j) %in% row.find)
#  print(temp2[i+j])




aa <- extractAlleles(object, which=c(1,2))
value="A"
apply(aa, 1, function(x) sum(x==value))
 extractAlleles(object, which=0)


unique(as.character(alleles(object)))

carrier(object)
carrier(object, allele.names="A")
carrier(object, allele.names="A")

carrier(object, allele.names=c("T","A"))



alleleCount(object,value="A")
alleleCount(object,value=alleleLevels(object))
as.character(unlist(alleleLevels(object)))



aa <- markerNames(object)

as.vector(aa)

markerInfo(object)


marker="c104t"

match(marker, as.vector(markerNames(object)))
